/* bz2compat.c: Compatibility layer between libbz2-0.9.x and libbz2-1.0.x
 * created 2000-Nov-26 22:13 jmk
 * autodate: 2000-Nov-27 01:22
 * 
 * by Jim Knoble <jmknoble@jmknoble.cx>
 * Copyright (C) 2000 Jim Knoble
 * 
 * Disclaimer:
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * express or implied, including but not limited to the warranties of
 * merchantability, fitness for a particular purpose and
 * noninfringement. In no event shall the author(s) be liable for any
 * claim, damages or other liability, whether in an action of
 * contract, tort or otherwise, arising from, out of or in connection
 * with the software or the use or other dealings in the software.
 * 
 * Permission to use, copy, modify, distribute, and sell this software
 * and its documentation for any purpose is hereby granted without
 * fee, provided that the above copyright notice appear in all copies
 * and that both that copyright notice and this permission notice
 * appear in supporting documentation.
 * 
 * This code is a thin wrapper around the API to bzip2-1.0.1 by Julian
 * Seward <jseward@acm.org>, and might be considered to be a
 * derivative work of bzip2.  In that case, this code might fall under
 * the license under which bzip2 is distributed; see that license for
 * details.
 */

#ifndef OLD_BZIP2

#include <stdio.h>
#include <bzlib.h>
#include "bz2compat.h"

int bzCompressInit ( 
      bz_stream* strm, 
      int        blockSize100k, 
      int        verbosity, 
      int        workFactor 
   ) 
{
   return(BZ2_bzCompressInit(strm, blockSize100k, verbosity, workFactor));
}

int bzCompress ( 
      bz_stream* strm, 
      int action 
   )
{
   return(BZ2_bzCompress(strm, action));
}

int bzCompressEnd ( 
      bz_stream* strm 
   )
{
   return(BZ2_bzCompressEnd(strm));
}

int bzDecompressInit ( 
      bz_stream *strm, 
      int       verbosity, 
      int       small
   )
{
   return(BZ2_bzDecompressInit(strm, verbosity, small));
}

int bzDecompress ( 
      bz_stream* strm 
   )
{
   return(BZ2_bzDecompress(strm));
}

int bzDecompressEnd ( 
      bz_stream *strm 
   )
{
   return(BZ2_bzDecompressEnd(strm));
}

#ifndef BZ_NO_STDIO
BZFILE* bzReadOpen ( 
      int*  bzerror,   
      FILE* f, 
      int   verbosity, 
      int   small,
      void* unused,    
      int   nUnused 
   )
{
   return(BZ2_bzReadOpen(bzerror, f, verbosity, small, unused, nUnused));
}

void bzReadClose ( 
      int*    bzerror, 
      BZFILE* b 
   )
{
   BZ2_bzReadClose(bzerror, b);
}

void bzReadGetUnused ( 
      int*    bzerror, 
      BZFILE* b, 
      void**  unused,  
      int*    nUnused 
   )
{
   BZ2_bzReadGetUnused(bzerror, b, unused, nUnused);
}

int bzRead ( 
      int*    bzerror, 
      BZFILE* b, 
      void*   buf, 
      int     len 
   )
{
   return(BZ2_bzRead(bzerror, b, buf, len));
}

BZFILE* bzWriteOpen ( 
      int*  bzerror,      
      FILE* f, 
      int   blockSize100k, 
      int   verbosity, 
      int   workFactor 
   )
{
   return(BZ2_bzWriteOpen(bzerror, f, blockSize100k, verbosity, workFactor));
}

void bzWrite ( 
      int*    bzerror, 
      BZFILE* b, 
      void*   buf, 
      int     len 
   )
{
   BZ2_bzWrite(bzerror, b, buf, len);
}

void bzWriteClose ( 
      int*          bzerror, 
      BZFILE*       b, 
      int           abandon, 
      unsigned int* nbytes_in, 
      unsigned int* nbytes_out 
   )
{
   BZ2_bzWriteClose(bzerror, b, abandon, nbytes_in, nbytes_out);
}

void bzWriteClose64 ( 
      int*          bzerror, 
      BZFILE*       b, 
      int           abandon, 
      unsigned int* nbytes_in_lo32, 
      unsigned int* nbytes_in_hi32, 
      unsigned int* nbytes_out_lo32, 
      unsigned int* nbytes_out_hi32
   )
{
   BZ2_bzWriteClose64(bzerror, b, abandon, nbytes_in_lo32, nbytes_in_hi32,
		      nbytes_out_lo32, nbytes_out_hi32);
}
#endif /* BZ_NO_STDIO */

int bzBuffToBuffCompress ( 
      char*         dest, 
      unsigned int* destLen,
      char*         source, 
      unsigned int  sourceLen,
      int           blockSize100k, 
      int           verbosity, 
      int           workFactor 
   )
{
   return(BZ2_bzBuffToBuffCompress(dest, destLen, source, sourceLen,
				   blockSize100k, verbosity, workFactor));
}

int bzBuffToBuffDecompress ( 
      char*         dest, 
      unsigned int* destLen,
      char*         source, 
      unsigned int  sourceLen,
      int           small, 
      int           verbosity 
   )
{
   return(BZ2_bzBuffToBuffDecompress(dest, destLen, source, sourceLen, small,
				     verbosity));
}

const char * bzlibVersion (
      void
   )
{
   return(BZ2_bzlibVersion());
}

#ifndef BZ_NO_STDIO
BZFILE * bzopen (
      const char *path,
      const char *mode
   )
{
   return(BZ2_bzopen(path, mode));
}

BZFILE * bzdopen (
      int        fd,
      const char *mode
   )
{
   return(BZ2_bzdopen(fd, mode));
}

int bzread (
      BZFILE* b, 
      void* buf, 
      int len 
   )
{
   return(BZ2_bzread(b, buf, len));
}

int bzwrite (
      BZFILE* b, 
      void*   buf, 
      int     len 
   )
{
   return(BZ2_bzwrite(b, buf, len));
}

int bzflush (
      BZFILE* b
   )
{
   return(BZ2_bzflush(b));
}

void bzclose (
      BZFILE* b
   )
{
   BZ2_bzclose(b);
}

const char * bzerror (
      BZFILE *b, 
      int    *errnum
   )
{
   return(BZ2_bzerror(b, errnum));
}
#endif /* BZ_NO_STDIO */

#endif /* OLD_BZIP2 */
