/* bz2compat.h: Compatibility layer between libbz2-0.9.x and libbz2-1.0.x
 * created 2000-Nov-26 22:06 jmk
 * autodate: 2000-Nov-27 01:21
 * 
 * by Jim Knoble <jmknoble@jmknoble.cx>
 * Copyright (C) 2000 Jim Knoble
 * 
 * Disclaimer:
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * express or implied, including but not limited to the warranties of
 * merchantability, fitness for a particular purpose and
 * noninfringement. In no event shall the author(s) be liable for any
 * claim, damages or other liability, whether in an action of
 * contract, tort or otherwise, arising from, out of or in connection
 * with the software or the use or other dealings in the software.
 * 
 * Permission to use, copy, modify, distribute, and sell this software
 * and its documentation for any purpose is hereby granted without
 * fee, provided that the above copyright notice appear in all copies
 * and that both that copyright notice and this permission notice
 * appear in supporting documentation.
 * 
 * This code is a thin wrapper around the API to bzip2-1.0.1 by Julian
 * Seward <jseward@acm.org>, and might be considered to be a
 * derivative work of bzip2.  In that case, this code might fall under
 * the license under which bzip2 is distributed; see that license for
 * details.
 */

#ifndef OLD_BZIP2

#ifndef H_BZ2COMPAT
#define H_BZ2COMPAT

#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */
   
int bzCompressInit ( 
      bz_stream* strm, 
      int        blockSize100k, 
      int        verbosity, 
      int        workFactor 
   );
int bzCompress ( 
      bz_stream* strm, 
      int action 
   );
int bzCompressEnd ( 
      bz_stream* strm 
   );
int bzDecompressInit ( 
      bz_stream *strm, 
      int       verbosity, 
      int       small
   );
int bzDecompress ( 
      bz_stream* strm 
   );
int bzDecompressEnd ( 
      bz_stream *strm 
   );

#ifndef BZ_NO_STDIO
BZFILE* bzReadOpen ( 
      int*  bzerror,   
      FILE* f, 
      int   verbosity, 
      int   small,
      void* unused,    
      int   nUnused 
   );
void bzReadClose ( 
      int*    bzerror, 
      BZFILE* b 
   );
void bzReadGetUnused ( 
      int*    bzerror, 
      BZFILE* b, 
      void**  unused,  
      int*    nUnused 
   );
int bzRead ( 
      int*    bzerror, 
      BZFILE* b, 
      void*   buf, 
      int     len 
   );
BZFILE* bzWriteOpen ( 
      int*  bzerror,      
      FILE* f, 
      int   blockSize100k, 
      int   verbosity, 
      int   workFactor 
   );
void bzWrite ( 
      int*    bzerror, 
      BZFILE* b, 
      void*   buf, 
      int     len 
   );
void bzWriteClose ( 
      int*          bzerror, 
      BZFILE*       b, 
      int           abandon, 
      unsigned int* nbytes_in, 
      unsigned int* nbytes_out 
   );
void bzWriteClose64 ( 
      int*          bzerror, 
      BZFILE*       b, 
      int           abandon, 
      unsigned int* nbytes_in_lo32, 
      unsigned int* nbytes_in_hi32, 
      unsigned int* nbytes_out_lo32, 
      unsigned int* nbytes_out_hi32
   );
#endif /* BZ_NO_STDIO */

int bzBuffToBuffCompress ( 
      char*         dest, 
      unsigned int* destLen,
      char*         source, 
      unsigned int  sourceLen,
      int           blockSize100k, 
      int           verbosity, 
      int           workFactor 
   );
int bzBuffToBuffDecompress ( 
      char*         dest, 
      unsigned int* destLen,
      char*         source, 
      unsigned int  sourceLen,
      int           small, 
      int           verbosity 
   );
const char * bzlibVersion (
      void
   );

#ifndef BZ_NO_STDIO
BZFILE * bzopen (
      const char *path,
      const char *mode
   );
BZFILE * bzdopen (
      int        fd,
      const char *mode
   );
int bzread (
      BZFILE* b, 
      void* buf, 
      int len 
   );
int bzwrite (
      BZFILE* b, 
      void*   buf, 
      int     len 
   );
int bzflush (
      BZFILE* b
   );
void bzclose (
      BZFILE* b
   );
const char * bzerror (
      BZFILE *b, 
      int    *errnum
   );
#endif /* BZ_NO_STDIO */
   
#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* H_BZ2COMPAT */

#endif /* OLD_BZIP2 */
